from mindsdb_sql.ast.base import ASTNode
from mindsdb_sql.utils import indent


class Identifier(ASTNode):
    def __init__(self, value, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.value = value

    def to_tree(self, *args, level=0, **kwargs):
        alias_str = f', alias={repr(self.alias)}' if self.alias else ''
        return indent(level) + f'Identifier(value={repr(self.value)}{alias_str})'

    def to_string(self, *args, **kwargs):
        return self.maybe_add_alias(str(self.value))




from .select import Select
from .constant import Constant, NullConstant
from .identifier import Identifier
from .operation import Operation, Function, BinaryOperation, UnaryOperation
from .order_by import OrderBy
from .join import Join
from .type_cast import TypeCast
from .tuple import Tuple
from .parameter import Parameter
